==> soplex-6.0.4-2-x86_64.pkg.tar.zst: usr/include/soplex/ratrecon.h <==
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/*                                                                           */
/*                  This file is part of the class library                   */
/*       SoPlex --- the Sequential object-oriented simPlex.                  */
/*                                                                           */
/*  Copyright (c) 1996-2023 Zuse Institute Berlin (ZIB)                      */
/*                                                                           */
/*  Licensed under the Apache License, Version 2.0 (the "License");          */
/*  you may not use this file except in compliance with the License.         */
/*  You may obtain a copy of the License at                                  */
/*                                                                           */
/*      http://www.apache.org/licenses/LICENSE-2.0                           */
/*                                                                           */
/*  Unless required by applicable law or agreed to in writing, software      */
/*  distributed under the License is distributed on an "AS IS" BASIS,        */
/*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. */
/*  See the License for the specific language governing permissions and      */
/*  limitations under the License.                                           */
/*                                                                           */
/*  You should have received a copy of the Apache-2.0 license                */
/*  along with SoPlex; see the file LICENSE. If not email to soplex@zib.de.  */
/*                                                                           */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

/**@file  ratrecon.h
 * @brief Rational reconstruction of solution vector
 */


#ifndef _RATRECON_H_
#define _RATRECON_H_

#include "soplex/spxdefines.h"
#include "soplex/rational.h"
#include "soplex/sol.h"
#include "soplex/basevectors.h"
#include "soplex/didxset.h"

namespace soplex
{
/** reconstruct a rational vector */
bool reconstructVector(VectorRational& input, const Rational& denomBoundSquared,
                       const DIdxSet* indexSet = 0);

/** reconstruct a rational solution */
bool reconstructSol(SolRational& solution);
} // namespace soplex

#include "soplex/ratrecon.hpp"

#endif // _RATRECON_H_

==> soplex-8.0.1-4-x86_64.pkg.tar.zst: usr/include/soplex/ratrecon.h <==
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/*                                                                           */
/*                  This file is part of the class library                   */
/*       SoPlex --- the Sequential object-oriented simPlex.                  */
/*                                                                           */
/*  Copyright (c) 1996-2026 Zuse Institute Berlin (ZIB)                      */
/*                                                                           */
/*  Licensed under the Apache License, Version 2.0 (the "License");          */
/*  you may not use this file except in compliance with the License.         */
/*  You may obtain a copy of the License at                                  */
/*                                                                           */
/*      http://www.apache.org/licenses/LICENSE-2.0                           */
/*                                                                           */
/*  Unless required by applicable law or agreed to in writing, software      */
/*  distributed under the License is distributed on an "AS IS" BASIS,        */
/*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. */
/*  See the License for the specific language governing permissions and      */
/*  limitations under the License.                                           */
/*                                                                           */
/*  You should have received a copy of the Apache-2.0 license                */
/*  along with SoPlex; see the file LICENSE. If not email to soplex@zib.de.  */
/*                                                                           */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

/**@file  ratrecon.h
 * @brief Rational reconstruction of solution vector
 */


#ifndef _RATRECON_H_
#define _RATRECON_H_

#include "soplex/spxdefines.h"
#include "soplex/rational.h"
#include "soplex/sol.h"
#include "soplex/basevectors.h"
#include "soplex/didxset.h"

namespace soplex
{
/** reconstruct a rational vector */
bool reconstructVector(VectorRational& input, const Rational& denomBoundSquared,
                       const DIdxSet* indexSet = nullptr);

/** reconstruct a rational solution */
bool reconstructSol(SolRational& solution);
} // namespace soplex

#include "soplex/ratrecon.hpp"

#endif // _RATRECON_H_
